clc
close all 

%% Import laminate data and calculate Vbi and Nsub

% Fill in the details of the cell laminate below
CV_data = xlsread('1-Al-BSF-1.xlsx'); %import CV data
Area = 153; %cell Area in cm^2
v_min = -2.0; %Set lowest voltage of CV data to be used for linear fitting. A minus sign corresponds to reverse bias. End voltage is automatically the maximum voltage of the dataset

% These lines extract the CV data 
V = CV_data(:,1); %V
Cp = (10^-6)*CV_data(:,2)/Area;  %F/cm2
index_v_first = find( V > v_min, 1 );
index_v_last = numel(V);
V = V(index_v_first:index_v_last);
Cp = Cp(index_v_first:index_v_last);

% Create linear fit
V_plot = linspace(-3,3,100000);
C_inv = 1./(Cp.^2);
fit_cell = polyfit(V,C_inv,1);
fit_cell_plot = fit_cell(2)+V_plot.*fit_cell(1);

% Calculate Vbi
cell_zero = find(fit_cell_plot<0,1);
Vbi_cell = V_plot(cell_zero) %in V

% Calculate Nsub
eps_si = 11.7;
eps_0 = 8.85*10^-14;
q = 1.602*10^-19;
slope_cell = abs(fit_cell(1)) ; %Retrieve slope as (F/cm2)^-2 (V^-1)
N_sub = (2/(q*eps_si*eps_0))*(1/slope_cell) %in cm^-3


%% Create plot

close all
figure
plot(V,C_inv,'x','MarkerSize',8,'Color','blue')
hold on 
plot(V_plot,fit_cell_plot)
legend('C-V measurement data','Linear fit')
ylabel('1/C^{2} ([F/cm^{2}]^{-2})')
xlabel('Voltage (V)')
grid on
xlim([-2 1])
ylim([0 max(C_inv*1.05)])
set(gca,'FontSize',12)

